@@ -2,20 +2,16 @@ from hashlib import md5
 
 from django.test import TestCase
 
-from easymode.tree.serializers import RecursiveXmlSerializer
-
-from easymode.tests.models import *
-from easymode.tests.testcases import initdb
-from easymode.utils.languagecode import get_language_codes
 from easymode import tree
-
-if 'en-us' not in get_language_codes():
-    raise Exception('the language "en-us" must be in your LANGUAGES to run the test suite')
+from easymode.utils.languagecode import get_real_fieldname
+from easymode.tests.models import TestModel, TestGenericFkModel, TagModel
+from easymode.tests.testcases import initdb
+from easymode.tree.serializers import RecursiveXmlSerializer
 
 
 __all__ = ('RecursiveSerializerTest',)
 
-CONFIRMED_XML_DIGEST = '02658bdf2a2e131ae4027396672037f7'
+CONFIRMED_XML_DIGEST = '2caeeae817ed103f8c92020717460a9d'
 
 
 @initdb
@@ -24,19 +20,7 @@ class RecursiveSerializerTest(TestCase):
     Test the functionality related to
     xmlserializable models.
     """
-    
-    def setUp(self):
-        t = TestModel(charfield='In lectus est, viverra a, ultricies ut, pulvinar vitae, tellus.')
-        t.save()
-        f = t.submodels.create(subcharfield="Quisque facilisis erat a dui.", subintegerfield=10)
-        s = t.submodels.create(subcharfield="Hoi ik ben de tweede first level sub node", subintegerfield=100)
-        w = t.secondsubmodels.create(ultrafield="Sed tempor. Ut felis. Maecenas erat.")
-        f.subsubmodels.create(subsubcharfield="Cras eu mauris.")
-        f.subsubmodels.create(subsubcharfield="Etiam imperdiet urna sit amet risus.")
-        s.subsubmodels.create(subsubcharfield="Proin tincidunt, velit vel porta elementum, magna diam molestie sapien, non aliquet massa pede eu diam.")
-        s.subsubmodels.create(subsubcharfield="Ut felis.")        
-        t.save()
-    
+    fixtures = ['tests-testmodel.xml']
     
     def test_create_test_models(self):
         """create test models"""
@@ -47,13 +31,14 @@ class RecursiveSerializerTest(TestCase):
         ser = RecursiveXmlSerializer()
         res = TestModel.objects.all()
         xml = ser.serialize(res)
+        
         assert(md5(xml).hexdigest() == CONFIRMED_XML_DIGEST)
         
     def test_model_to_xml(self):
         """test the __xml__ method added to the model"""
         xml = TestModel.objects.get(pk=1).__xml__()
         assert( md5(xml).hexdigest() == CONFIRMED_XML_DIGEST)
- 
+     
     def test_model_to_xml_with_xml_function(self):
         """test the xml function in package tree"""
         xml = tree.xml(TestModel.objects.get(pk=1))
@@ -70,11 +55,30 @@ class RecursiveSerializerTest(TestCase):
         r.save()
         r.relateds.create(name='ik ben graaf')
         r.save()
-        # print r
-        # print "\n"
-        # print r.__dict__
-        # print "\n"
-        # print r.__class__.__dict__
-        # print "\n"
-        # print r.__xml__()
-        assert("This test must be implemented, it does work!" is False)
\ No newline at end of file
+        xml = TestGenericFkModel.objects.all().__xml__()
+        assert(xml.index( 'ik ben cool') != -1)
+        assert(xml.index( 'ik ben graaf') != -1)
+        r.relateds.create(name='ik lust spruitjes')
+        r.save()
+        xml = TestGenericFkModel.objects.all().__xml__()
+        assert(xml.index( 'ik lust spruitjes') != -1)
+    
+    def test_natural_keys(self):
+        "natural keys will show up in the xml"
+        
+        xml_with_natural_keys = tree.xml(TestModel.objects.all())
+        assert(xml_with_natural_keys.find('<natural>In lectus est, viverra a, ultricies ut, pulvinar vitae, tellus.</natural>') != -1)
+    
+    def test_many_to_many_field(self):
+        "ManyToManyField should be followed in one direction, like foreign keys"
+        
+        data = tree.xml(TestModel.objects.all())
+        assert(data.index('<field type="CharField" name="value">good</field>')!= -1)
+        assert(data.index('<field type="CharField" name="value">ugly</field>')!= -1)
+        
+        bad_tag = TagModel.objects.get(value_en='bad')
+        first_item = TestModel.objects.get(pk=1)
+        first_item.tags.add(bad_tag)
+        first_item.save()
+        data = tree.xml(TestModel.objects.all())
+        assert(data.index('<field type="CharField" name="value">bad</field>')!= -1)
\ No newline at end of file
